import { List } from 'immutable';
import { Observable } from 'rxjs';
import { MeetingService } from '../wac-proxy/wac-stack/MeetingService';
import { Meeting } from './Meeting';
import { MeetingParticipant } from './MeetingParticipant';
export interface MeetingUpdateData extends Partial<Pick<Meeting, 'name' | 'validSince' | 'validUntil'>> {
    id: string;
    participants?: Iterable<MeetingParticipant>;
    password?: string;
}
/**
 * ContactManager instance is obtained by calling the {@link Session#getMeetingManager}
 * method of {@link Session} and must not be directly instantiated.
 */
export declare class MeetingManager {
    /** @private */
    private initLock;
    /** @private */
    private meetingService;
    /** @private */
    private meetingsSubject;
    /** @private */
    private meetings$;
    /** @ignore */
    constructor(meetingService: MeetingService);
    /** @ignore */
    init(): Promise<void>;
    /** @ignore */
    uninit(): Promise<void>;
    /**
     * Retrieves a list with the available meetings
     * @return {Observable<ImmutableList<Meeting>>}
     */
    getMeetings$(): Observable<List<Meeting>>;
    /**
     * Retrieves a meeting with the following id
     * @param {string} meetingId Id of the meeeting to retrieve
     * @return {Observable<ImmutableList<Meeting>>}
     */
    getMeeting(meetingId: string): Promise<Meeting>;
    /**
     * Creates a meeting
     * @param {string} name The name of the meeting.
     * @param {Iterable<MeetingParticipant>} participants The participants of the new meeting session.
     * @param {number} validSince The timestamp of the moment when the meeting starts.
     * @param {number} [validUntil] The timestamp until the meeting is valid.
     * @param {boolean} [sendSms=false] If true, an invitation for the meeting will be sent in an SMS by the server.
     * @param {string} [password] Password for meeting access protection
     * @return {Promise<Meeting>} The just created meeting
     */
    createMeeting(name: string, participants: Iterable<MeetingParticipant>, validSince: number, validUntil?: number, sendSms?: boolean, password?: string): Promise<Meeting>;
    /**
     * Updates a meeting
     * @param {Meeting} meeting
     * @param {boolean} [sendSms=false] Flag used to decide whether to send an SMS message or not
     * @return {Promise<Meeting>}
     */
    saveMeeting(meeting: MeetingUpdateData, sendSms?: boolean): Promise<Meeting>;
    /**
     * Removes a meeting given its id
     * @param {object} meeting
     * @param {string} meeting.id
     */
    removeMeeting({ id }: Pick<Meeting, 'id'>): Promise<void>;
    /** @private */
    private onMeeting;
    /** @private */
    private onMeetingDelete;
    /** @private */
    private notifyMeeting;
}
